import 'package:domain/entity/service_in_progress_entity.dart';
import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:plugin_basic/provider/app_config/app_config_service.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/color_utils.dart';
import 'package:shared/utils/ext_dart.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:shared/utils/screen_util.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/my_button.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/my_text_view.dart';
import 'package:widgets/my_appbar.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:widgets/utils/dark_theme_util.dart';
import 'package:widgets/widget_export.dart';

import '../../../components/repair_status_card_item.dart';
import '../../../constants_services.dart';
import '../../../router/page/services_page_router.dart';
import 'history_vm.dart';
import '../../../components/status_card_item.dart';

@RoutePage()
class RepairHistoryPage extends HookConsumerWidget {
  const RepairHistoryPage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance({BuildContext? context}) {
    if (context != null) {
      context.router.push(const RepairHistoryPageRoute());
    } else {
      appRouter.push(const RepairHistoryPageRoute());
    }
  }


  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final vm = ref.read(repairHistoryVmProvider.notifier);
    final state = ref.watch(repairHistoryVmProvider);
    // final appConfigState = ref.watch(appConfigServiceProvider)

    int? cleanServiceTypeId = servicesConstants.inquiryServicesType['repairAirConditioner']?['id'];


    useEffect(() {
      // 组件挂载时执行 - 执行接口请求
      Future.microtask(() => vm.initPageData());
      return () {
        // 组件卸载时执行
        Log.d("history_page 组件卸载时执行");
      };
    }, []);

    return Scaffold(
      // appBar: MyAppBar.appBar(
      //   context,
      //   "History",
      //   backgroundColor: context.appColors.whiteBG,
      // ),
      backgroundColor: DarkThemeUtil.multiColors(context, ColorUtils.string2Color('#F2F3F6'), darkColor: Colors.black)?? Colors.black,
      body: SizedBox(
          width: double.infinity,
          height: double.infinity,
          child: EasyRefresh(
            key: ValueKey('history'),
            controller: vm.refreshController,
            // 上拉加载
            onLoad: () async {
              Log.d("----onLoad");
              vm.loadMore();
            },
            // 下拉刷新
            onRefresh: () async {
              Log.d("----onRefresh");
              vm.onRefresh();
            },
            child: LoadStateLayout(
              state: state.loadingState,
              errorMessage: state.errorMessage,
              errorRetry: () {
                vm.retryRequest();
              },
              successSliverWidget: [
                SliverList(
                  delegate: SliverChildBuilderDelegate(
                    (context, index) {
                      return _buildRepairHistoryItem(
                        context,
                        ref,
                        state.list[index],
                        vm,
                          cleanServiceTypeId
                      ).onTap(() {
                      });
                    },
                    childCount: state.list.length,
                  ),
                )
              ],
            ),
          ).marginOnly(left: 15, right: 15, top: 0, bottom: 15)),
    );
  }

  Widget _buildRepairHistoryItem(BuildContext context, WidgetRef ref, ServiceInProgressList item, vm, int? cleanServiceTypeId){
    return Container(
      margin: const EdgeInsets.only(top: 10),
      width: double.infinity,
      decoration: BoxDecoration(
        color: context.appColors.whiteBG,
        borderRadius: BorderRadius.circular(8),
        boxShadow: [
          BoxShadow(
            color: DarkThemeUtil.multiColors(context, ColorUtils.string2Color('#E5E5E5'), darkColor: Colors.transparent)?? Colors.transparent,
            offset: const Offset(0, 2),
            blurRadius: 8,
          ),
        ],
      ),
      child: RepairStausCardItem(
        key: UniqueKey(),
        cardHeight: 115.0,
        item: item,
        onClickCard: (dynamic value) async {
          // Log.d("点击了喜欢按钮  --id:${item['id']}- $collectionValue");
          // int id = item['id'];
          // return await vm.handlerClickCollection(id, collectionValue);
        },
      ),
    );
  }
}
